@@ -23,14 +23,17 @@
 
 typedef enum
 {
-    SEARCH_TYPE_EXACT,
-    SEARCH_TYPE_SUBSTRING
+    GL_QUERY_SEARCH_TYPE_SUBSTRING,
+    GL_QUERY_SEARCH_TYPE_EXACT
 } GlQuerySearchType;
 
 /* Resultant query passed to journal model from eventviewlist */
 typedef struct GlQuery
 {
     GPtrArray *queryitems;   /* array of GlQueryItem structs */
+    GlQuerySearchType search_type;    /* indicates if search field is passed as exact match */
+    guint64 start_timestamp;
+    guint64 end_timestamp;
 } GlQuery;
 
 #define GL_TYPE_JOURNAL_MODEL gl_journal_model_get_type()
@@ -48,6 +51,10 @@ void                    gl_query_add_match                              (GlQuery
                                                                          const gchar *field_value,
                                                                          GlQuerySearchType search_type);
 
+void                    gl_query_set_journal_timestamp_range            (GlQuery *query,
+                                                                         guint64 start_timestamp,
+                                                                         guint64 end_timestamp);
+
 void                    gl_journal_model_set_matches                    (GlJournalModel      *model,
                                                                          const gchar * const *matches);
 
@@ -61,4 +68,7 @@ GArray *                gl_journal_model_get_boot_ids                   (GlJourn
 gchar *                 gl_journal_model_get_current_boot_time          (GlJournalModel *model,
                                                                          const gchar *boot_match);
 
+void                    gl_query_set_search_type                        (GlQuery *query,
+                                                                         GlQuerySearchType search_type);
+
 #endif
